Constants
Traits
- Find
Heavy Transaction Bursts - A trait for finding the heaviest “bursts” of transaction activity over a given time window.
Functions
- build_
date_ windows - Build the date windows of size
window_sizedays by summing daily totals in[date, date+window_size-1]. - collect_
daily_ totals - Build a map of (NaiveDate -> total) for the given transactions
- merge_
overlapping_ burst_ windows - Merge overlapping date windows (ignoring the total amount here) into
[start, end]pairs. Overlap is defined as date ranges that are consecutive or intersecting. - print_
merged_ bursts - Print the final merged date windows, each with a recomputed total, and then the individual transaction lines within that date range.
- sort_
windows_ desc - Sort the date windows by the total MonetaryAmount in descending order.